
|Python35|_ |Doc|_

.. |Python35| image:: https://img.shields.io/badge/python-3.5-blue.svg
.. _Python35: https://badge.fury.io/py/genibabel

.. |Doc| image:: https://readthedocs.org/projects/genibabel/badge/?version=latest
.. _Doc: https://genibabel.readthedocs.io/en/latest/?badge=latest

=========
genibabel
=========

Package to generate/request a genetic reference as defined in
https://biothings.intra.cea.fr.





